import {
  Box,
  Button,
  Paper,
  Typography,
  Menu,
  MenuItem,
  TextField,
} from "@mui/material";
import {
  BackButton,
  createSightStore,
  editSightStore,
  languageStore,
  SelectArticleModal,
  TabPanel,
} from "@shared";
import {
  LanguageSwitcher,
  ReactMarkdownComponent,
  ReactMarkdownEditor,
} from "@widgets";
import { ImagePlus, Plus } from "lucide-react";
import { observer } from "mobx-react-lite";
import { useEffect, useState } from "react";
import { toast } from "react-toastify";

export const RightWidgetTab = observer(
  ({ value, index }: { value: number; index: number }) => {
    const [anchorEl, setAnchorEl] = useState<null | HTMLElement>(null);
    const { createNewRightArticle, updateRightArticleInfo } = createSightStore;
    const { sight, getRightArticles, updateSight } = editSightStore;
    const { language } = languageStore;

    useEffect(() => {
      if (sight.common.id) {
        getRightArticles(sight.common.id);
      }
    }, [sight.common.id]);

    const [activeArticleIndex, setActiveArticleIndex] = useState<number | null>(
      null
    );
    const [isSelectModalOpen, setIsSelectModalOpen] = useState(false);

    const open = Boolean(anchorEl);
    const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
      setAnchorEl(event.currentTarget);
    };
    const handleClose = () => {
      setAnchorEl(null);
    };

    const handleSelectArticle = (index: number) => {
      setActiveArticleIndex(index);
    };

    const handleCreateNew = () => {
      createNewRightArticle();
      handleClose();
    };

    const handleSelectExisting = () => {
      setIsSelectModalOpen(true);
      handleClose();
    };

    const handleCloseSelectModal = () => {
      setIsSelectModalOpen(false);
    };

    const handleArticleSelect = () => {
      // TODO: Implement article selection logic
      handleCloseSelectModal();
    };

    const handleSave = async () => {
      await updateSight();
      toast.success("Достопримечательность сохранена");
    };

    return (
      <TabPanel value={value} index={index}>
        <LanguageSwitcher />
        <Box
          sx={{
            display: "flex",
            flexDirection: "column",
            height: "100%",
            minHeight: "calc(100vh - 200px)",
            gap: 2,
            paddingBottom: "70px",
            position: "relative",
          }}
        >
          <BackButton />

          <Box sx={{ display: "flex", flexGrow: 1, gap: 2.5 }}>
            <Box className="flex flex-col w-[75%] gap-2">
              <Box className="w-full flex gap-2">
                <Box className="relative w-[20%] h-[70vh] flex flex-col rounded-2xl overflow-y-auto gap-3 border border-gray-300 p-3">
                  <Box className="flex flex-col gap-3 max-h-[60vh] overflow-y-auto">
                    <Box
                      // onClick={() => setMediaType("preview")}
                      className="w-full bg-gray-200 p-4 rounded-2xl cursor-pointer text-sm hover:bg-gray-300 transition-all duration-300"
                    >
                      <Typography>Предпросмотр медиа</Typography>
                    </Box>

                    {sight[language].right.map((article, index) => (
                      <Box
                        key={index}
                        className="w-full bg-gray-200 p-4 rounded-2xl text-sm cursor-pointer hover:bg-gray-300 transition-all duration-300"
                        onClick={() => handleSelectArticle(index)}
                      >
                        <Typography>{article.heading}</Typography>
                      </Box>
                    ))}
                  </Box>
                  <button
                    className="w-10 h-10 bg-blue-500 rounded-full absolute bottom-5 left-5 flex items-center justify-center"
                    onClick={handleClick}
                  >
                    <Plus size={20} color="white" />
                  </button>
                  <Menu
                    id="basic-menu"
                    anchorEl={anchorEl}
                    open={open}
                    onClose={handleClose}
                    MenuListProps={{
                      "aria-labelledby": "basic-button",
                    }}
                    sx={{ mt: 1 }}
                  >
                    <MenuItem onClick={handleCreateNew}>
                      <Typography>Создать новую</Typography>
                    </MenuItem>
                    <MenuItem onClick={handleSelectExisting}>
                      <Typography>Выбрать существующую статью</Typography>
                    </MenuItem>
                  </Menu>
                </Box>

                <Box className="w-[80%] border border-gray-300 rounded-2xl p-3">
                  {activeArticleIndex !== null && (
                    <>
                      <Box className="flex justify-end gap-2 mb-3">
                        <Button variant="contained" color="primary">
                          Открепить
                        </Button>
                        <Button variant="contained" color="success">
                          Удалить
                        </Button>
                      </Box>
                      <Box sx={{ display: "flex", gap: 3, flexGrow: 1 }}>
                        <Box
                          sx={{
                            flex: 2,
                            display: "flex",
                            flexDirection: "column",
                            gap: 2,
                            maxHeight: "70%",
                          }}
                        >
                          <TextField
                            label="Название информации"
                            value={
                              sight[language].right[activeArticleIndex].heading
                            }
                            onChange={(e) =>
                              updateRightArticleInfo(
                                activeArticleIndex,
                                language,
                                e.target.value,
                                sight[language].right[activeArticleIndex].body
                              )
                            }
                            variant="outlined"
                            fullWidth
                          />

                          <ReactMarkdownEditor
                            value={
                              sight[language].right[activeArticleIndex].body
                            }
                            onChange={(value) =>
                              updateRightArticleInfo(
                                activeArticleIndex,
                                language,
                                sight[language].right[activeArticleIndex]
                                  .heading,
                                value
                              )
                            }
                          />
                          {/* <MediaArea
                            articleId={1}
                            mediaIds={[]}
                            deleteMedia={() => {}}
                          /> */}
                        </Box>
                      </Box>
                    </>
                  )}
                </Box>
              </Box>
            </Box>

            <Box className="w-[25%] mr-10">
              {activeArticleIndex !== null && (
                <Paper
                  className="flex-1 flex flex-col rounded-2xl"
                  elevation={2}
                >
                  <Box
                    className="rounded-2xl overflow-hidden"
                    sx={{
                      width: "100%",
                      height: "75vh",
                      background: "#877361",
                      borderColor: "grey.300",
                      display: "flex",
                      flexDirection: "column",
                    }}
                  >
                    <Box
                      sx={{
                        width: "100%",
                        height: 200,
                        flexShrink: 0,
                        backgroundColor: "rgba(0,0,0,0.1)",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                      }}
                    >
                      <ImagePlus size={48} color="white" />
                    </Box>

                    <Box
                      sx={{
                        width: "100%",
                        minHeight: "70px",
                        background: "#877361",
                        display: "flex",
                        flexShrink: 0,
                        alignItems: "center",
                        borderBottom: "1px solid rgba(255,255,255,0.1)",
                        px: 2,
                      }}
                    >
                      <Typography variant="h6" color="white">
                        {sight[language].right[activeArticleIndex].heading ||
                          "Выберите статью"}
                      </Typography>
                    </Box>

                    <Box
                      sx={{
                        px: 2,
                        flexGrow: 1,
                        overflowY: "auto",
                        backgroundColor: "#877361",
                        color: "white",
                        py: 1,
                      }}
                    >
                      {sight[language].right[activeArticleIndex].body ? (
                        <ReactMarkdownComponent
                          value={sight[language].right[activeArticleIndex].body}
                        />
                      ) : (
                        <Typography
                          color="rgba(255,255,255,0.7)"
                          sx={{ textAlign: "center", mt: 4 }}
                        >
                          Предпросмотр статьи появится здесь
                        </Typography>
                      )}
                    </Box>
                  </Box>
                </Paper>
              )}
            </Box>
          </Box>

          <Box
            sx={{
              position: "absolute",
              bottom: 0,
              right: 0,
              padding: 2,
              backgroundColor: "background.paper",
              width: "100%",
              display: "flex",
              justifyContent: "flex-end",
            }}
          >
            <Button variant="contained" color="success" onClick={handleSave}>
              Сохранить изменения
            </Button>
          </Box>
        </Box>

        <SelectArticleModal
          open={isSelectModalOpen}
          onClose={handleCloseSelectModal}
          onSelectArticle={handleArticleSelect}
        />
      </TabPanel>
    );
  }
);
